# Webform GoHighLevel Integration

## Description

The Webform GoHighLevel Integration module allows you to seamlessly send webform submissions from your Drupal site to the GoHighLevel CRM. With this module, you can map webform fields to GoHighLevel fields, ensuring accurate data transfer for effective customer relationship management.

## Features

- Integrates GoHighLevel API with Drupal Webforms.
- Configurable field mappings per webform via the Webform handler settings.
- Supports sending webform data securely to GoHighLevel.
- Fully customizable for unique business needs.

## Requirements

- Drupal 10 or 11.
- The [Webform](https://www.drupal.org/project/webform) module must be installed and enabled.
- A valid GoHighLevel API key.

## Installation

1. Download and install the module:
   - Place the `webform_gohighlevel` folder in the `modules/custom/` directory of your Drupal installation.
   - Enable the module via the Extend page in Drupal or using Drush:
     ```bash
     drush en webform_gohighlevel
     ```

2. Configure permissions:
   - Navigate to **People > Permissions** and assign appropriate permissions for managing and using the module.

3. Set up GoHighLevel API credentials:
   - Navigate to **Configuration > Webform GoHighLevel Settings**.
   - Enter your GoHighLevel API key.

## Configuration

1. **Add the Webform Handler**:
   - Go to any Webform on your site.
   - Click on **Settings > Emails/Handlers**.
   - Add the **GoHighLevel Handler**.
   In the GoHighLevel Handler Settings, do the following:

   - API Key: Enter your GoHighLevel API key.
   - Tag: Specify the tag you want to assign to contacts created or updated in GoHighLevel (e.g., "Webform Submission").
   - Field Mappings: Map the Webform fields to the corresponding GoHighLevel fields, including any custom fields like "Webform Message."
   
   - Save the handler configuration.

2. Important: Mapping a Message/Enquiry Field
To successfully map a "Message" or "Enquiry" text area field from your webform to GoHighLevel:
1. Log in to your GoHighLevel account.
2. Create a custom field named **"Webform Message"** under the **Custom Fields** section of your GoHighLevel settings.

3. **Testing the Integration**:
   - Submit the webform to ensure data is successfully sent to GoHighLevel.
   - Check your GoHighLevel CRM to verify the submission.

## Troubleshooting

- Ensure the GoHighLevel API key is correct.
- Verify that the required Webform fields are mapped correctly.
- Check the Drupal logs (**Reports > Recent Log Messages**) for errors.

## Roadmap

Planned features for future releases:
- Support for additional GoHighLevel objects (e.g., opportunities, pipelines).
- Enhanced error handling and logging.
- Bulk submissions to GoHighLevel.

## Maintainers

- Gary Pratten (mylocaltrades)(https://www.drupal.org/u/mylocaltrades) (mylocaltrades)

Contributions, feature requests, and bug reports are welcome. Please submit them via the [issue queue](https://www.drupal.org/project/issues/webform_gohighlevel).